# PWRPY

PWRPY is a Python library for interacting with the PWR network.
It provides an easy interface for wallet management and sending transactions on PWR.

## Installation

Run: `pip install pwrpy`

The library needs the `PRC_NODE_URL` environment variable set to https://pwrrpc.pwrlabs.io/.
